﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace SteamConverter
{
    public partial class Form_Main : Form
    {
        public Form_Main()
        {
            InitializeComponent();
        }

        System.IO.StreamWriter saveStream;
        Int32 conversionCount = 0;
        
        private void Button_OpenSQLFile_Click(object sender, EventArgs e)
        {
            OpenFileDialog openFile = new OpenFileDialog();
            openFile.Filter = "SQL Files|*.sql";

            if (openFile.ShowDialog() != DialogResult.OK)
                return;

            if (System.IO.File.Exists(openFile.FileName + ".backup"))
            {
                DialogResult result = MessageBox.Show("The file " + openFile.FileName + ".backup already exists, which means you've most likely used this program already. Do you want to overwrite this file?", "Confim file overwrite?", MessageBoxButtons.YesNo);

                if (result == System.Windows.Forms.DialogResult.Yes)
                    System.IO.File.Delete(openFile.FileName + ".backup");
                else
                    return;
            }

            conversionCount = 0;
            Label_SourceFile.Text = openFile.FileName;
            Label_SourceFile.ForeColor = Color.Black;

            System.IO.File.Copy(openFile.FileName, openFile.FileName + ".backup");
            System.IO.StreamReader fileStream = new System.IO.StreamReader(openFile.FileName + ".backup");
            saveStream = new System.IO.StreamWriter(openFile.FileName, false);

            String line;
            String newLine;

            while ((line = fileStream.ReadLine()) != null)
            {
                while (ProcessLine(line, out newLine) == true)
                    line = newLine;

                Application.DoEvents();
                saveStream.WriteLine(newLine);
            }

            fileStream.Close();
            fileStream.Dispose();

            saveStream.Close();
            saveStream.Dispose();

            Label_Status.Text = "Converted " + conversionCount.ToString() + " steam IDs successfully.";
            System.Media.SystemSounds.Beep.Play();
        }

        private Boolean ProcessLine(String line, out String newLine) {
            Int32 pos = line.IndexOf("STEAM_0:");
            newLine = line;

            if (pos == -1)
                return false;

            Int32 endPos = line.IndexOf('\'', pos) - pos;

            if (endPos == -1)
                return false;

            String legacySteamId = line.Substring(pos, endPos);

            Int32 universe = Convert.ToInt32(legacySteamId.Substring(8, 1));
            Int32 numberPart = Convert.ToInt32(legacySteamId.Substring(10));

            String newSteamId = String.Format("[U:1:{0}]", numberPart * 2 + universe);
            newLine = newLine.Replace(legacySteamId, newSteamId);
            Label_Status.Text = "Converted " + legacySteamId + " to " + newSteamId + ".";
            conversionCount++;
            return true;
        }
    }
}
